@@ -69,18 +69,14 @@ class OrderedList:
 
         return count
 
-# Mock test
+
+"""
+Only mock test
 
 search = OrderedList()
 
 search.add(70)
-search.add(31)
-search.add(49)
-search.add(50)
-search.add(-10)
-search.add(81)
-search.add(26)
 
 print(search.size())
 print(search.search_obj(93))
-print(search.search_obj(26))
+"""
\ No newline at end of file
