@@ -134,11 +134,14 @@ class DFS:
 					explored.append(v)
 		return explored
 
-# Mock test
+"""
+Only mock test
+
 s = LinkedList()
 
 s.procedure_push(1)
 
 print(str(s.procedure_size()))
 print(str(s.procedure_peek()))
-print(str(s.procedure_is_empty()))
\ No newline at end of file
+print(str(s.procedure_is_empty()))
+"""
\ No newline at end of file
